/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NavigationService } from './../navigation/navigation.service';
import { ChangeDetectorRef } from '@angular/core';
import { PagerElementComponent } from './pager-element.component';
import { PagerContextService, PagerContextChanges } from './pager-context.service';
import { PageSizeItem } from './pagesize-item.interface';
import { ContextService } from '../common/provider.service';
import * as i0 from "@angular/core";
/**
 * Displays a drop-down list for the page size selection ([see example](slug:pager_template_grid#toc-using-built-in-pager-components)).
 */
export declare class PagerPageSizesComponent extends PagerElementComponent {
    protected pagerContext: PagerContextService;
    navigationService: NavigationService;
    /**
     * The page sizes collection. Can be an Array of numbers and/or [`PageSizeItem`](slug:api_grid_pagesizeitem) objects
     * ([see example](slug:pager_template_grid))
     */
    set pageSizes(pageSizes: Array<PageSizeItem | number>);
    get pageSizes(): Array<PageSizeItem | number>;
    /**
     * @hidden
     *
     * @readonly
     */
    get classes(): boolean;
    /**
     * @hidden
     *
     * @readonly
     */
    get showInitialPageSize(): boolean;
    private _pageSizes;
    constructor(ctx: ContextService, cd: ChangeDetectorRef, pagerContext: PagerContextService, navigationService: NavigationService);
    /**
     * @hidden
     */
    pageSizeChange(value: any): void;
    /**
     * @hidden
     */
    getValue(page: PageSizeItem): number;
    protected onChanges({ total, skip, pageSize }: PagerContextChanges): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<PagerPageSizesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PagerPageSizesComponent, "kendo-pager-page-sizes", never, { "pageSizes": "pageSizes"; }, {}, never, never, true, never>;
}
